@@ -5,11 +5,11 @@
 //           This file provides an SIMD version of the functions.
 // Language: C
 // Date:     06-Oct-2019
-// Ver:      19-Oct-2019.
+// Ver:      02-Jan-2020.
 //
 //------------------------------------------------------------------------------
 //
-//   Copyright 2014 - 2019    Michael Griffin    <m12.griffin@gmail.com>
+//   Copyright 2014 - 2020    Michael Griffin    <m12.griffin@gmail.com>
 //
 //   Licensed under the Apache License, Version 2.0 (the "License");
 //   you may not use this file except in compliance with the License.
@@ -45,6 +45,7 @@
 
 // Auto generated code goes below.
 
+
 /*--------------------------------------------------------------------------- */
 /* The following series of functions reflect the different parameter options possible.
    arraylen = The length of the data arrays.
@@ -78,11 +79,10 @@ char lt_signed_char_1_simd(Py_ssize_t arraylen, signed char *data1, signed char
 	alignedlength = arraylen - (arraylen % CHARSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += CHARSIMDSIZE) {
 		datasliceleft = vld1_s8( &data1[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft < datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vclt_s8(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
 		if (!(vreinterpret_u64_u8(resultslice) == 0xffffffffffffffff)) {
 			return 0;
@@ -90,7 +90,7 @@ char lt_signed_char_1_simd(Py_ssize_t arraylen, signed char *data1, signed char
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (!(data1[index] < param)) {
 			return 0;
 		}
@@ -126,11 +126,10 @@ char lt_signed_char_3_simd(Py_ssize_t arraylen, signed char param, signed char *
 	alignedlength = arraylen - (arraylen % CHARSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += CHARSIMDSIZE) {
 		datasliceright = vld1_s8( &data2[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft < datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vclt_s8(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
 		if (!(vreinterpret_u64_u8(resultslice) == 0xffffffffffffffff)) {
 			return 0;
@@ -138,7 +137,7 @@ char lt_signed_char_3_simd(Py_ssize_t arraylen, signed char param, signed char *
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (!(param < data2[index])) {
 			return 0;
 		}
@@ -167,12 +166,11 @@ char lt_signed_char_5_simd(Py_ssize_t arraylen, signed char *data1, signed char
 	alignedlength = arraylen - (arraylen % CHARSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += CHARSIMDSIZE) {
 		datasliceleft = vld1_s8( &data1[index]);
 		datasliceright = vld1_s8( &data2[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft < datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vclt_s8(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
 		if (!(vreinterpret_u64_u8(resultslice) == 0xffffffffffffffff)) {
 			return 0;
@@ -180,7 +178,7 @@ char lt_signed_char_5_simd(Py_ssize_t arraylen, signed char *data1, signed char
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (!(data1[index] < data2[index])) {
 			return 0;
 		}
@@ -193,6 +191,10 @@ char lt_signed_char_5_simd(Py_ssize_t arraylen, signed char *data1, signed char
 #endif
 
 
+/*--------------------------------------------------------------------------- */
+
+
+
 /*--------------------------------------------------------------------------- */
 /* The following series of functions reflect the different parameter options possible.
    arraylen = The length of the data arrays.
@@ -226,11 +228,10 @@ char lt_unsigned_char_1_simd(Py_ssize_t arraylen, unsigned char *data1, unsigned
 	alignedlength = arraylen - (arraylen % CHARSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += CHARSIMDSIZE) {
 		datasliceleft = vld1_u8( &data1[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft < datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vclt_u8(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
 		if (!(vreinterpret_u64_u8(resultslice) == 0xffffffffffffffff)) {
 			return 0;
@@ -238,7 +239,7 @@ char lt_unsigned_char_1_simd(Py_ssize_t arraylen, unsigned char *data1, unsigned
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (!(data1[index] < param)) {
 			return 0;
 		}
@@ -274,11 +275,10 @@ char lt_unsigned_char_3_simd(Py_ssize_t arraylen, unsigned char param, unsigned
 	alignedlength = arraylen - (arraylen % CHARSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += CHARSIMDSIZE) {
 		datasliceright = vld1_u8( &data2[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft < datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vclt_u8(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
 		if (!(vreinterpret_u64_u8(resultslice) == 0xffffffffffffffff)) {
 			return 0;
@@ -286,7 +286,7 @@ char lt_unsigned_char_3_simd(Py_ssize_t arraylen, unsigned char param, unsigned
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (!(param < data2[index])) {
 			return 0;
 		}
@@ -315,12 +315,11 @@ char lt_unsigned_char_5_simd(Py_ssize_t arraylen, unsigned char *data1, unsigned
 	alignedlength = arraylen - (arraylen % CHARSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += CHARSIMDSIZE) {
 		datasliceleft = vld1_u8( &data1[index]);
 		datasliceright = vld1_u8( &data2[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft < datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vclt_u8(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
 		if (!(vreinterpret_u64_u8(resultslice) == 0xffffffffffffffff)) {
 			return 0;
@@ -328,7 +327,7 @@ char lt_unsigned_char_5_simd(Py_ssize_t arraylen, unsigned char *data1, unsigned
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (!(data1[index] < data2[index])) {
 			return 0;
 		}
@@ -341,6 +340,10 @@ char lt_unsigned_char_5_simd(Py_ssize_t arraylen, unsigned char *data1, unsigned
 #endif
 
 
+/*--------------------------------------------------------------------------- */
+
+
+
 /*--------------------------------------------------------------------------- */
 /* The following series of functions reflect the different parameter options possible.
    arraylen = The length of the data arrays.
@@ -374,11 +377,10 @@ char lt_signed_short_1_simd(Py_ssize_t arraylen, signed short *data1, signed sho
 	alignedlength = arraylen - (arraylen % SHORTSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
 		datasliceleft = vld1_s16( &data1[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft < datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vclt_s16(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
 		if (!(vreinterpret_u64_u16(resultslice) == 0xffffffffffffffff)) {
 			return 0;
@@ -386,7 +388,7 @@ char lt_signed_short_1_simd(Py_ssize_t arraylen, signed short *data1, signed sho
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (!(data1[index] < param)) {
 			return 0;
 		}
@@ -422,11 +424,10 @@ char lt_signed_short_3_simd(Py_ssize_t arraylen, signed short param, signed shor
 	alignedlength = arraylen - (arraylen % SHORTSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
 		datasliceright = vld1_s16( &data2[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft < datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vclt_s16(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
 		if (!(vreinterpret_u64_u16(resultslice) == 0xffffffffffffffff)) {
 			return 0;
@@ -434,7 +435,7 @@ char lt_signed_short_3_simd(Py_ssize_t arraylen, signed short param, signed shor
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (!(param < data2[index])) {
 			return 0;
 		}
@@ -463,12 +464,11 @@ char lt_signed_short_5_simd(Py_ssize_t arraylen, signed short *data1, signed sho
 	alignedlength = arraylen - (arraylen % SHORTSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
 		datasliceleft = vld1_s16( &data1[index]);
 		datasliceright = vld1_s16( &data2[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft < datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vclt_s16(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
 		if (!(vreinterpret_u64_u16(resultslice) == 0xffffffffffffffff)) {
 			return 0;
@@ -476,7 +476,7 @@ char lt_signed_short_5_simd(Py_ssize_t arraylen, signed short *data1, signed sho
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (!(data1[index] < data2[index])) {
 			return 0;
 		}
@@ -489,6 +489,10 @@ char lt_signed_short_5_simd(Py_ssize_t arraylen, signed short *data1, signed sho
 #endif
 
 
+/*--------------------------------------------------------------------------- */
+
+
+
 /*--------------------------------------------------------------------------- */
 /* The following series of functions reflect the different parameter options possible.
    arraylen = The length of the data arrays.
@@ -522,11 +526,10 @@ char lt_unsigned_short_1_simd(Py_ssize_t arraylen, unsigned short *data1, unsign
 	alignedlength = arraylen - (arraylen % SHORTSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
 		datasliceleft = vld1_u16( &data1[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft < datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vclt_u16(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
 		if (!(vreinterpret_u64_u16(resultslice) == 0xffffffffffffffff)) {
 			return 0;
@@ -534,7 +537,7 @@ char lt_unsigned_short_1_simd(Py_ssize_t arraylen, unsigned short *data1, unsign
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (!(data1[index] < param)) {
 			return 0;
 		}
@@ -570,11 +573,10 @@ char lt_unsigned_short_3_simd(Py_ssize_t arraylen, unsigned short param, unsigne
 	alignedlength = arraylen - (arraylen % SHORTSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
 		datasliceright = vld1_u16( &data2[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft < datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vclt_u16(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
 		if (!(vreinterpret_u64_u16(resultslice) == 0xffffffffffffffff)) {
 			return 0;
@@ -582,7 +584,7 @@ char lt_unsigned_short_3_simd(Py_ssize_t arraylen, unsigned short param, unsigne
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (!(param < data2[index])) {
 			return 0;
 		}
@@ -611,12 +613,11 @@ char lt_unsigned_short_5_simd(Py_ssize_t arraylen, unsigned short *data1, unsign
 	alignedlength = arraylen - (arraylen % SHORTSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
 		datasliceleft = vld1_u16( &data1[index]);
 		datasliceright = vld1_u16( &data2[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft < datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vclt_u16(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
 		if (!(vreinterpret_u64_u16(resultslice) == 0xffffffffffffffff)) {
 			return 0;
@@ -624,7 +625,7 @@ char lt_unsigned_short_5_simd(Py_ssize_t arraylen, unsigned short *data1, unsign
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (!(data1[index] < data2[index])) {
 			return 0;
 		}
@@ -636,3 +637,6 @@ char lt_unsigned_short_5_simd(Py_ssize_t arraylen, unsigned short *data1, unsign
 
 #endif
 
+
+/*--------------------------------------------------------------------------- */
+
